@@ -2,7 +2,7 @@ package Test2::API::Instance;
 use strict;
 use warnings;
 
-our $VERSION = '1.302065';
+our $VERSION = '1.302066';
 
 
 our @CARP_NOT = qw/Test2::API Test2::API::Instance Test2::IPC::Driver Test2::Formatter/;
@@ -304,6 +304,13 @@ sub ipc_enable_shm {
     $self->{+_TID} = get_tid() unless defined $self->{+_TID};
 
     my ($ok, $err) = try {
+        # SysV IPC can be available but not enabled.
+        #
+        # In some systems (*BSD) accessing the SysV IPC APIs without
+        # them being enabled can cause a SIGSYS.  We suppress the SIGSYS
+        # and then get ENOSYS from the calls.
+        local $SIG{SYS} = 'IGNORE';
+
         require IPC::SysV;
 
         my $ipc_key = IPC::SysV::IPC_PRIVATE();
